# Appfy [![Build Status](https://travis-ci.org/Appfy/appfy-slush.svg?branch=master)](https://travis-ci.org/Appfy/appfy-slush)
> Minimalistic framework to scaffold and build web applications with Angular.js and Node. Based on MEAN stack.

## Requirement
- Node 4+
- Npm 2+
- Bower 1.7+
- Gulp 3.8+

## Dependencies

```
$ npm install -g bower
$ npm install -g gulp
```

## Install
```
$ npm install -g appfy@latest
```

## Usage
```
$ appfy new [app_name]
```

## CLI
Command Line Interface
- ##### General
  - [x] Show help
  `$ appfy --help`
  - [x] Show current version
  `$ appfy --version` 
  - [x] Create new application 
  `$ appfy new [app_name]`  
  
- ##### Client
  - [ ] Module               
  `$ appfy new module [module_name]`  
  - [ ] Component           
  `$ appfy new component [module_name] [component_name]`
  - [ ] Directive            
  `$ appfy new directive [module_name] [directive_name]`
  - [ ] Filter               
  `$ appfy new filter [module_name] [filter_name]`  
  - [ ] Service              
  `$ appfy new service [module_name] [service_name]`  
  - [ ] Factory              
  `$ appfy new factory [module_name] [factory_name]`  
  - [ ] Controller           
  `$ appfy new controller [module_name] [controller_name]`
  
- ##### Server
  - [ ] API endpoint        
  `$ appfy new api [endpoint]`  
  - [ ] Endpoint model       
  `$ appfy new api:model [endpoint] [model_name]`  
  - [ ] Endpoint controller  
  `$ appfy new api:controller [endpoint] [controller_name]`
  
- ##### Environment
  - [ ] Serves both client and server
  `$ appfy serve`
  - [ ] Serves client       
  `$ appfy serve --client`  
  - [ ] Serves client in distribution mode   
  `$ appfy serve --client-dist`
  - [ ] Serves API server
  `$ appfy serve --api` 


- ##### Deployment
  - [ ] build and deploy client     
  `$ appfy build --client`  
  - [ ] build and deploy server api     
  `$ appfy build --server`  
  

## Application Structure

```
├── README.md
├──.client.build                                <- client deploy
├──.server.build                                <- server deploy
├── gulpfile.ts                                 <- configuration of the gulp tasks
├── karma.conf.js                               <- configuration of the test runner
├── package.json                                <- dependencies of the project
├── protractor.conf.js                          <- e2e tests configuration
├── bin                                         <- deploy and build executables
├── server                                      <- source code of backend application
├── client                                      <- source code of frontend application
│   └── src
│       ├── app
│       │   └── core                            <- appfy core modules
│       │   │   ├── errors
│       │   │   ├── login
│       │   │   ├── page
│       │   │   ├── user
│       │   │   ├── utils
│       │   └── modules                          <- third-party modules
│       │   │   ├── home
│       │   │   │   ├── home.config.js
│       │   │   │   ├── home.component.js
│       │   │   │   ├── home.spec.js
│       │   │   │   ├── home.html
│       │   │   │   ├── home.css
│       │   └── themes         
│       │   │   ├── default
│       │   │   │   ├── theme.html
│       │   ├── index.less
│       │   ├── index.module.js                  <- main module
│       │   ├── vendor.less
│       ├── assets
│       └── index.html                           <- main template
└── .gitignore                                   <- ignored files